==> fcl_0.3.2.orig.tar.gz: fcl-0.3.2/src/articulated_model/joint_config.cpp <==
/*
 * Software License Agreement (BSD License)
 *
 *  Copyright (c) 2011, Willow Garage, Inc.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   * Neither the name of Willow Garage, Inc. nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 */

/** \author Dalibor Matura, Jia Pan */

#include "fcl/articulated_model/joint_config.h"
#include "fcl/articulated_model/joint.h"

namespace fcl
{

JointConfig::JointConfig() {}

JointConfig::JointConfig(const JointConfig& joint_cfg) :
  joint_(joint_cfg.joint_),
  values_(joint_cfg.values_),
  limits_min_(joint_cfg.limits_min_),
  limits_max_(joint_cfg.limits_max_)
{
}

JointConfig::JointConfig(const boost::shared_ptr<Joint>& joint,
                         FCL_REAL default_value,
                         FCL_REAL default_value_min,
                         FCL_REAL default_value_max) :
  joint_(joint)
{
  values_.resize(joint->getNumDofs(), default_value);
  limits_min_.resize(joint->getNumDofs(), default_value_min);
  limits_max_.resize(joint->getNumDofs(), default_value_max);
}

std::size_t JointConfig::getDim() const
{
  return values_.size();
}

FCL_REAL JointConfig::getValue(std::size_t i) const
{
  return values_[i];
}

FCL_REAL& JointConfig::getValue(std::size_t i)
{
  return values_[i];
}

FCL_REAL JointConfig::getLimitMin(std::size_t i) const
{
  return limits_min_[i];
}

FCL_REAL& JointConfig::getLimitMin(std::size_t i)
{
  return limits_min_[i];
}

FCL_REAL JointConfig::getLimitMax(std::size_t i) const
{
  return limits_max_[i];
}

FCL_REAL& JointConfig::getLimitMax(std::size_t i)
{
  return limits_max_[i];
}



boost::shared_ptr<Joint> JointConfig::getJoint() const
{
  return joint_.lock();
}

}

==> fcl_0.5.0.orig.tar.gz: fcl-0.5.0/src/articulated_model/joint_config.cpp <==
/*
 * Software License Agreement (BSD License)
 *
 *  Copyright (c) 2011-2014, Willow Garage, Inc.
 *  Copyright (c) 2014-2016, Open Source Robotics Foundation
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   * Neither the name of Open Source Robotics Foundation nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 */

/** \author Dalibor Matura, Jia Pan */

#include "fcl/articulated_model/joint_config.h"
#include "fcl/articulated_model/joint.h"

namespace fcl
{

JointConfig::JointConfig() {}

JointConfig::JointConfig(const JointConfig& joint_cfg) :
  joint_(joint_cfg.joint_),
  values_(joint_cfg.values_),
  limits_min_(joint_cfg.limits_min_),
  limits_max_(joint_cfg.limits_max_)
{
}

JointConfig::JointConfig(const std::shared_ptr<Joint>& joint,
                         FCL_REAL default_value,
                         FCL_REAL default_value_min,
                         FCL_REAL default_value_max) :
  joint_(joint)
{
  values_.resize(joint->getNumDofs(), default_value);
  limits_min_.resize(joint->getNumDofs(), default_value_min);
  limits_max_.resize(joint->getNumDofs(), default_value_max);
}

std::size_t JointConfig::getDim() const
{
  return values_.size();
}

FCL_REAL JointConfig::getValue(std::size_t i) const
{
  return values_[i];
}

FCL_REAL& JointConfig::getValue(std::size_t i)
{
  return values_[i];
}

FCL_REAL JointConfig::getLimitMin(std::size_t i) const
{
  return limits_min_[i];
}

FCL_REAL& JointConfig::getLimitMin(std::size_t i)
{
  return limits_min_[i];
}

FCL_REAL JointConfig::getLimitMax(std::size_t i) const
{
  return limits_max_[i];
}

FCL_REAL& JointConfig::getLimitMax(std::size_t i)
{
  return limits_max_[i];
}



std::shared_ptr<Joint> JointConfig::getJoint() const
{
  return joint_.lock();
}

}
